Skip to contents

A fabricated data set containing information about different movies

Usage

movies

Format

movies

A data frame with 10 rows and 4 columns:

id

A running id number

name

Name of the moview

abstract

A short abstract, imagined from chatgpt based on the movie title

year

A review of the movie, imagined from chatgtp based on the movie title

#' @source Communication Department of the University of Münster (k.maubach@uni-muenster.de and jakob.juenger@uni-muenster.de).