Authenticates against the Databoard-API and stores the returned access token in the system environment for subsequent calls. Please contact the Digital Media and Computational Methods research unit to acquire a user account. Keep your login data and access token private.
Usage
da_login(
username,
password,
server = getOption("databoard.baseurl", DATABOARD_BASEURL),
verbose = FALSE,
silent = TRUE
)Arguments
- username
Character. Username for the login. If missing, the user is prompted interactively.
- password
Character. Password for the login. If missing, the user is prompted interactively with a masked prompt (via the
askpasspackage if available, otherwise an unmaskedreadline()fallback).- server
Character. Base URL of the Databoard server. Defaults to
https://databoard.uni-muenster.de/.- verbose
Logical. If
TRUE, subsequent API calls will print additional diagnostic information. Stored in the environment variableDATABOARD_VERBOSE.- silent
Logical. If
TRUE, failing API calls will not stop processing further tasks. Stored in the environment variableDATABOARD_SILENT.